pitchtools.instantiate_pitch_and_interval_test_collection
=========================================================

.. autofunction:: abjad.tools.pitchtools.instantiate_pitch_and_interval_test_collection.instantiate_pitch_and_interval_test_collection
